#!/usr/bin/env python3

import json
import pyinotify
from datetime import datetime
import sys
import time
import os

current_dir = os.path.dirname(os.path.realpath(__file__))
parent_dir = os.path.dirname(current_dir)
sys.path.append(parent_dir)

from lib.sys_utils import IqLogger
from lib.cached_network_status import CachedNetworkStatus
from lib.mqtt_client import MQTTClient

file_to_watch = '/etc/wb-connection-manager.conf'

# Класс для мониторинга изменений файла и обновления данных в CachedNetworkStatus
class ConfigFileHandler(pyinotify.ProcessEvent):
    def __init__(self):
        super().__init__()
        self.update_cached_network_status(self.read_config_file())

    def process_IN_MODIFY(self, event):
        if event.pathname == file_to_watch:
            print(f"File '{file_to_watch}' was modified.")
            self.update_cached_network_status(self.read_config_file())

    def read_config_file(self):
        try:
            with open(file_to_watch, 'r') as file:
                content = file.read()
                if not content:  # Проверка на пустое содержимое
                    print(f"File '{file_to_watch}' is temporarily empty. Skipping this update.")
                    return None
                return json.loads(content)
        except FileNotFoundError:
            print(f"File '{file_to_watch}' not found.")
        except json.JSONDecodeError as e:
            print(f"Error decoding JSON: {e}. Skipping this update.")
        except Exception as e:
            print(f"An error occurred: {e}")
        return None

    def update_cached_network_status(self, data):
        if data is None:
            return
        cached_data = CachedNetworkStatus()
        with cached_data.lock:
            for tier, interfaces in data.get("tiers", {}).items():
                cached_data.data["Priorities"][tier] = interfaces
            cached_data.update_time()
            # MQTTClient(logger=IqLogger()).publish(cached_data.data)

def start_monitoring():
    time.sleep(30) # ждем настройки сети, чтобы избежать оценки мусора
    wm = pyinotify.WatchManager()
    mask = pyinotify.IN_MODIFY
    notifier = pyinotify.Notifier(wm, ConfigFileHandler())
    wm.add_watch(file_to_watch, mask)
    print(f"Monitoring '{file_to_watch}' for changes...")
    notifier.loop()
