#!/usr/bin/env python3

import re
import json
import sys
import select
import time
import os

current_dir = os.path.dirname(os.path.realpath(__file__))
parent_dir = os.path.dirname(current_dir)
sys.path.append(parent_dir)

from lib.sys_utils import IqLogger

def remove_ansi_codes(text):
    # Удаление ANSI кодов цвета и стиля текста
    ansi_escape = re.compile(r'\x1B[@-_][0-?]*[ -/]*[@-~]')
    return ansi_escape.sub('', text)

def parse_value(value):
    if ';' in value and ':' in value:
        parts = value.split(';')
        return {part.split(': ', 1)[0].strip(): parse_value(part.split(': ', 1)[1].strip()) for part in parts if ': ' in part}

    elif ',' in value:
        return [parse_value(part.strip()) for part in value.split(',')]

    return value

def preprocess_text(text):
    text = remove_ansi_codes(text)
    lines = text.split('\n')
    processed_lines = []
    is_array = False

    for line in lines:
        if '|' in line and ':' in line:
            pre_pipe_chars = line.find('|')
            post_pipe_chars = line.find(':') - pre_pipe_chars
            continuation_pattern = r'^ {' + str(pre_pipe_chars) + r'}\| {' + str(post_pipe_chars - 1) + r'}'
            break

    for i in range(len(lines)):
        if re.match(continuation_pattern, lines[i]):
            if is_array:
                processed_lines[-1] += lines[i].split('|')[-1].strip()
            else:
                processed_lines[-1] += '; ' + lines[i].split('|')[-1].strip()
        else:
            processed_lines.append(lines[i])
            is_array = lines[i].endswith(', ')

    return '\n'.join(processed_lines)

def process_text(text):
    preprocessed_text = preprocess_text(text)
    pattern = r'(?: +([\w ]+\w)? +\| +(\w[^:]+): ([^\n]+[^ ]))'
    matches = re.findall(pattern, preprocessed_text)

    structured_data = {}
    current_section = None

    for section, key, value in matches:
        key = key.strip()
        value = parse_value(value.strip())

        if section.strip():
            current_section = section.strip()
            structured_data[current_section] = {}

        if current_section:
            structured_data[current_section][key] = value
        else:
            structured_data[key] = value

    return structured_data

def convert_mmcli_to_json(input_text):
    """ Преобразует текстовый вывод mmcli в JSON """
    return process_text(input_text)

if __name__ == "__main__":
    if len(sys.argv) > 1:
        file_path = sys.argv[1]
        with open(file_path, 'r') as file:
            text = file.read()
    elif select.select([sys.stdin,],[],[],0.0)[0]:
        text = sys.stdin.read()
    else:
        print("No input provided.")
        sys.exit(1)

    print(convert_mmcli_to_json(text))
