#!/usr/bin/env python3

import time
import os

current_dir = os.path.dirname(os.path.realpath(__file__))
parent_dir = os.path.dirname(current_dir)
sys.path.append(parent_dir)

from lib.sys_utils import IqLogger
from lib.sys_utils import ShellCommand

MY_TIMEOUT_S = 300  # Время ожидания подключения к интернету в секундах

class SimplifiedNetUtils(ShellCommand):
    def __init__(self, logger=None):
        super().__init__(IqLogger())

    def controller_reboot(self):
        self.logger.warning("!!! CONTROLLER REBOOT !!!")
        self.command_exec('reboot')

    def _check_internet(self, timeout_sec=5):
        test_hosts = ["www.google.com", "1.1.1.1"]  # Примеры хостов для проверки
        for hostname in test_hosts:
            cmd = "ping -c 1 -w {0} {1} > /dev/null".format(timeout_sec, hostname)
            res, _, _ = self.command_exec(cmd)
            if res == 0:
                return True
        return False

    def monitor_internet_connection(self):
        start_time = time.time()
        while True:
            if self._check_internet():
                start_time = time.time()
            elif time.time() - start_time > MY_TIMEOUT_S:
                self.controller_reboot()
                break
            time.sleep(10)

    def _wlan_quality(self):
        cmd = "iwconfig wlan0 | grep -i quality"
        ret, out, err = self.command_exec(cmd, timeout=15)
        if (ret is None) or (ret != 0):
            return None

        result = {}
        for part in out.strip().lower().split('  '):
            r = part.split('=')
            if len(r) != 2:
                continue
            result[r[0]] = r[1]
        return result

    def enable_wifi(self):
        self.command_exec("ifconfig wlan0 up")

    def disable_wifi(self):
        self.command_exec("ifconfig wlan0 down")

    def connect_to_wifi(self, ssid, password):
        cmd = "iwconfig wlan0 essid {0} key s:{1}".format(ssid, password)
        self.command_exec(cmd)

# Пример использования класса
net_utils = SimplifiedNetUtils()
net_utils.monitor_internet_connection()
