#!/usr/bin/env python3

import subprocess
import os
import time
import threading

PING_SERVERS = ["iqnergy.com", "debian.org", "ya.ru", "google.com"]
PING_INTERVAL = 10  # Интервал между попытками пинга в секундах
PING_TIMEOUT = 2  # Таймаут для каждого пинга в секундах
MAX_DURATION_WITHOUT_NETWORK = 60*30  # Максимальное время без сети в секундах

def is_network_available(server):
    """
    Проверяет доступность сети, пингуя указанный сервер.
    """
    try:
        subprocess.check_output(["ping", "-c", "1", "-W", str(PING_TIMEOUT), server], stderr=subprocess.STDOUT)
        return True
    except subprocess.CalledProcessError:
        return False

def network_monitor_task():
    """
    Задача мониторинга сети. Перезагружает контроллер, если сеть отсутствует дольше MAX_DURATION_WITHOUT_NETWORK.
    """
    last_successful_ping = time.time()

    while True:
        if any(is_network_available(server) for server in PING_SERVERS):
            last_successful_ping = time.time()
        else:
            if time.time() - last_successful_ping > MAX_DURATION_WITHOUT_NETWORK:
                print("Сеть отсутствует слишком долго. Перезагрузка.")
                time.sleep(5)
                os.system("halt")
                break

        time.sleep(PING_INTERVAL)

if __name__ == "__main__":
    network_monitor_thread = threading.Thread(target=network_monitor_task)
    network_monitor_thread.daemon = True
    network_monitor_thread.start()
